/* WooCommerce Variation Visual Editor app
 * Original author: troll_winner@mail.ru
 * Further changes, comments: troll_winner@mail.ru
 */

(function (root, factory) {
    'use strict';

    if (typeof define === 'function' && define.amd) {
        define(['jquery'], factory);
    } else if (typeof exports === 'object'
        && typeof module !== 'undefined'
        && typeof require === 'function'
    ) {
        module.exports = factory(require('jquery'));
    } else {
        factory(root.jQuery);
    }
})(this, function ($) {
    'use strict';

    function replaceAreaByButton(element) {
        $(element).find('[name*="variable_description"]:not(.screen-reader-text)').each(function () {
            $(this).addClass('screen-reader-text')
                .attr('data-component', 'wcvve-shared-editor-target')
                .before(' <button class="button button-large" data-component="wcvve-shared-editor-open">'
                    + '<span class="screen-reader-text">Edit</span>✎'
                    + '</button> ');
        });
    }

    $(document)
        // product variations are loaded
        .on('woocommerce_variations_loaded', '#woocommerce-product-data', function () {
            replaceAreaByButton(this);
        })

        // variation is added
        .on('woocommerce_variations_added', '#variable_product_options', function () {
            replaceAreaByButton(this);
        })

        // open shared wp-editor modal
        .on('click', '[data-component~="wcvve-shared-editor-open"]', function (event) {
            event.preventDefault();

            var $element = $(this);
            var $target = $element.next('[data-component~="wcvve-shared-editor-target"]');
            var $sharedEditorModal = $('#wcvve-shared-editor-modal');

            $sharedEditorModal.addClass('is-opened').data('target', $target);

            // set editor content
            if ($('#wp-wcvve-shared-editor-wrap').hasClass('tmce-active')
                && window.tinyMCE.get('wcvve-shared-editor')
            ) {
                window.tinyMCE.get('wcvve-shared-editor').setContent($target.val());
            } else {
                $('#wcvve-shared-editor').val($target.val());
            }
        })

        // modal save click
        .on('click', '#wcvve-shared-editor-save', function () {
            var $sharedEditorModal = $('#wcvve-shared-editor-modal');
            var content = $('#wcvve-shared-editor').val();

            // get editor content
            if ($('#wp-wcvve-shared-editor-wrap').hasClass('tmce-active')
                && window.tinyMCE.get('wcvve-shared-editor')
            ) {
                content = window.tinyMCE.get('wcvve-shared-editor').getContent();
            }

            $sharedEditorModal.data('target').val(content).trigger('change');
        })

        // modal close click
        .on('click', '[data-component~="wcvve-modal-close"]', function () {
            return $(this).closest('[data-component~="wcvve-modal"]').removeClass('is-opened');
        });
});
